fsm package
===========

Submodules
----------

fsm module
----------------------

.. autoclass:: fsm.InvalidTransition
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: fsm.FiniteStateMachineMixin
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: fsm
    :members:
    :undoc-members:
    :show-inheritance:
